@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "customtoolswidgetng.h"
@@ -39,15 +27,14 @@ public:
     QList<PimCommon::CustomToolsViewInterface *> mListInterfaceView;
 };
 
-CustomToolsWidgetNg::CustomToolsWidgetNg(KActionCollection *ac, QWidget *parent)
+CustomToolsWidgetNg::CustomToolsWidgetNg(QWidget *parent)
     : QWidget(parent)
     , d(new PimCommon::CustomToolsWidgetNgPrivate)
 {
-    QHBoxLayout *lay = new QHBoxLayout(this);
+    auto *lay = new QHBoxLayout(this);
     d->mStackedWidget = new QStackedWidget;
     d->mStackedWidget->setObjectName(QStringLiteral("stackedwidget"));
     lay->addWidget(d->mStackedWidget);
-    initializeView(ac);
     hide();
 }
 
@@ -56,9 +43,14 @@ CustomToolsWidgetNg::~CustomToolsWidgetNg()
     delete d;
 }
 
-void CustomToolsWidgetNg::initializeView(KActionCollection *ac)
+void CustomToolsWidgetNg::addCustomToolViewInterface(PimCommon::CustomToolsViewInterface *plugin)
+{
+    d->mListInterfaceView.append(plugin);
+    d->mStackedWidget->addWidget(plugin);
+}
+
+void CustomToolsWidgetNg::initializeView(KActionCollection *ac, const QVector<CustomToolsPlugin *> &localPluginsList)
 {
-    const QVector<CustomToolsPlugin *> localPluginsList = PimCommon::CustomToolsPluginManager::self()->pluginsList();
     for (CustomToolsPlugin *plugin : localPluginsList) {
         PimCommon::CustomToolsViewInterface *localCreateView = plugin->createView(ac, this);
         d->mListInterfaceView.append(localCreateView);
