@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "logactivitiesdialogtest.h"
@@ -41,18 +30,18 @@ LogActivitiesDialogTest::~LogActivitiesDialogTest()
 void LogActivitiesDialogTest::shouldHaveDefaultValue()
 {
     PimCommon::LogActivitiesDialog w;
-    QVBoxLayout *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
 
-    PimCommon::LogActivitiesWidget *mLogWidget = w.findChild<PimCommon::LogActivitiesWidget *>(QStringLiteral("logwidget"));
+    auto *mLogWidget = w.findChild<PimCommon::LogActivitiesWidget *>(QStringLiteral("logwidget"));
     QVERIFY(mLogWidget);
 
-    QCheckBox *mEnableLogActivities = w.findChild<QCheckBox *>(QStringLiteral("enablelogactivities"));
+    auto *mEnableLogActivities = w.findChild<QCheckBox *>(QStringLiteral("enablelogactivities"));
     QVERIFY(mEnableLogActivities);
     QVERIFY(!mEnableLogActivities->text().isEmpty());
     QVERIFY(!mEnableLogActivities->isChecked());
 
-    QDialogButtonBox *buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto *buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
 
     const QList<QAbstractButton *> lstButtonBox = buttonBox->buttons();
@@ -71,9 +60,9 @@ void LogActivitiesDialogTest::shouldHaveDefaultValue()
 void LogActivitiesDialogTest::shouldClearLog()
 {
     PimCommon::LogActivitiesDialog w;
-    QDialogButtonBox *buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto *buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
 
-    PimCommon::LogActivitiesWidget *mLogWidget = w.findChild<PimCommon::LogActivitiesWidget *>(QStringLiteral("logwidget"));
+    auto *mLogWidget = w.findChild<PimCommon::LogActivitiesWidget *>(QStringLiteral("logwidget"));
 
     QVERIFY(mLogWidget->log().isEmpty());
 
@@ -98,7 +87,7 @@ void LogActivitiesDialogTest::shouldHaveCorrectLogActivities()
 {
     PimCommon::LogActivitiesManager::self()->setEnableLogActivities(true);
     PimCommon::LogActivitiesDialog w;
-    QCheckBox *mEnableLogActivities = w.findChild<QCheckBox *>(QStringLiteral("enablelogactivities"));
+    auto *mEnableLogActivities = w.findChild<QCheckBox *>(QStringLiteral("enablelogactivities"));
     QVERIFY(mEnableLogActivities->isChecked());
 }
 
